==> estateplat-common-1.2.4-20211027.055955-921-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXtYh.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * Created by zdd on 2016/1/20.
 * 银行信息属性
 */
@Table(name = "bdc_xt_yh")
public class BdcXtYh implements Serializable {
    @Id
    private String yhid;
    private String yhmc;
    private String zjlx;
    private String zjbh;
    private String bz;
    private String txdz;//通讯地址
    private String yb;//邮编
    private String fzr;//负责人
    private String fzrlxdh;//负责人联系电话
    private String dwdm;//单位代码
    private String sfgz;//是否挂账
    private String sftysf;//是否统一收费
    private String sfjcpttysf;//是否集成平台统一收费
    private Date basj;//备案时间
    private String sfdz;//是否打证

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/9/21
     * @description 银行编号，具有唯一约束。编号规则：银行缩写_行政区代码，比如，ICBC_3201，表示中国工商银行南京分行
     */
    private String yhbh;
    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/9/21
     * @description 上级银行id，即父银行id
     */
    private String sjyhid;

    /**
     * @author <a href="mailto:guting@gtmap.cn">guting</a>
     * @version 1.0 2020/1/15
     * @description 代理人
     */
    private String dlr;
    /**
     * @author <a href="mailto:guting@gtmap.cn">guting</a>
     * @version 1.0 2020/1/15
     * @description 代理人证件类型
     */
    private String dlrzjlx;
    /**
     * @author <a href="mailto:guting@gtmap.cn">guting</a>
     * @version 1.0 2020/1/15
     * @description 代理人证件号
     */
    private String dlrzjh;

    /**
     * @author <a href="mailto:guting@gtmap.cn">guting</a>
     * @version 1.0 2020/8/27
     * @description 代理人联系电话
     */
    private String dlrlxdh;

    private String yhfr;//银行法人

    private String yhfrzjzl;//银行法人证件种类

    private String yhfrzjh;//银行法人证件号

    private String yhfrdh;//银行法人电话

    private String qlrxz;//权利人性质

    public String getTxdz() {
        return txdz;
    }

    public void setTxdz(String txdz) {
        this.txdz = txdz;
    }

    public String getYb() {
        return yb;
    }

    public void setYb(String yb) {
        this.yb = yb;
    }

    public String getFzr() {
        return fzr;
    }

    public void setFzr(String fzr) {
        this.fzr = fzr;
    }

    public String getFzrlxdh() {
        return fzrlxdh;
    }

    public void setFzrlxdh(String fzrlxdh) {
        this.fzrlxdh = fzrlxdh;
    }

    public String getYhid() {
        return yhid;
    }

    public void setYhid(String yhid) {
        this.yhid = yhid;
    }

    public String getYhmc() {
        return yhmc;
    }

    public void setYhmc(String yhmc) {
        this.yhmc = yhmc;
    }

    public String getZjlx() {
        return zjlx;
    }

    public void setZjlx(String zjlx) {
        this.zjlx = zjlx;
    }

    public String getZjbh() {
        return zjbh;
    }

    public void setZjbh(String zjbh) {
        this.zjbh = zjbh;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getYhbh() {
        return yhbh;
    }

    public void setYhbh(String yhbh) {
        this.yhbh = yhbh;
    }

    public String getSjyhid() {
        return sjyhid;
    }

    public void setSjyhid(String sjyhid) {
        this.sjyhid = sjyhid;
    }

    public String getYhfr() {
        return yhfr;
    }

    public void setYhfr(String yhfr) {
        this.yhfr = yhfr;
    }

    public String getSfgz() {
        return sfgz;
    }

    public void setSfgz(String sfgz) {
        this.sfgz = sfgz;
    }

    public String getSftysf() {
        return sftysf;
    }

    public void setSftysf(String sftysf) {
        this.sftysf = sftysf;
    }

    public String getYhfrzjzl() {
        return yhfrzjzl;
    }

    public void setYhfrzjzl(String yhfrzjzl) {
        this.yhfrzjzl = yhfrzjzl;
    }

    public String getYhfrzjh() {
        return yhfrzjh;
    }

    public void setYhfrzjh(String yhfrzjh) {
        this.yhfrzjh = yhfrzjh;
    }

    public String getYhfrdh() {
        return yhfrdh;
    }

    public void setYhfrdh(String yhfrdh) {
        this.yhfrdh = yhfrdh;
    }

    public String getSfjcpttysf() {
        return sfjcpttysf;
    }

    public void setSfjcpttysf(String sfjcpttysf) {
        this.sfjcpttysf = sfjcpttysf;
    }

    public String getDlr() {
        return dlr;
    }

    public void setDlr(String dlr) {
        this.dlr = dlr;
    }

    public String getDlrzjlx() {
        return dlrzjlx;
    }

    public void setDlrzjlx(String dlrzjlx) {
        this.dlrzjlx = dlrzjlx;
    }

    public String getDlrzjh() {
        return dlrzjh;
    }

    public void setDlrzjh(String dlrzjh) {
        this.dlrzjh = dlrzjh;
    }

    public String getDlrlxdh() {
        return dlrlxdh;
    }

    public void setDlrlxdh(String dlrlxdh) {
        this.dlrlxdh = dlrlxdh;
    }

    public Date getBasj() {
        return basj;
    }

    public void setBasj(Date basj) {
        this.basj = basj;
    }

    public String getSfdz() {
        return sfdz;
    }

    public void setSfdz(String sfdz) {
        this.sfdz = sfdz;
    }

    public String getQlrxz() {
        return qlrxz;
    }

    public void setQlrxz(String qlrxz) {
        this.qlrxz = qlrxz;
    }
}

==> estateplat-common-1.2.4-20220125.064734-971-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXtYh.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * Created by zdd on 2016/1/20.
 * 银行信息属性
 */
@Table(name = "bdc_xt_yh")
public class BdcXtYh implements Serializable {
    @Id
    private String yhid;
    private String yhmc;
    private String zjlx;
    private String zjbh;
    private String bz;
    private String txdz;//通讯地址
    private String yb;//邮编
    private String fzr;//负责人
    private String fzrlxdh;//负责人联系电话
    private String dwdm;//单位代码
    private String sfgz;//是否挂账
    private String sftysf;//是否统一收费
    private String sfjcpttysf;//是否集成平台统一收费
    private Date basj;//备案时间
    private String sfdz;//是否打证
    private String yhbh;//银行编号，具有唯一约束。编号规则：银行缩写_行政区代码，比如，ICBC_3201，表示中国工商银行南京分行
    private String sjyhid;//上级银行id，即父银行id
    private String dlr;//代理人
    private String dlrzjlx;//代理人证件类型
    private String dlrzjh;//代理人证件号
    private String dlrlxdh;//代理人联系电话
    private String yhfr;//银行法人
    private String yhfrzjzl;//银行法人证件种类
    private String yhfrzjh;//银行法人证件号
    private String yhfrdh;//银行法人电话
    private String qlrxz;//权利人性质
    private String lzr;//领证人
    private String lzrzjh;//领证人证件号

    public String getYhid() {
        return yhid;
    }

    public void setYhid(String yhid) {
        this.yhid = yhid;
    }

    public String getYhmc() {
        return yhmc;
    }

    public void setYhmc(String yhmc) {
        this.yhmc = yhmc;
    }

    public String getZjlx() {
        return zjlx;
    }

    public void setZjlx(String zjlx) {
        this.zjlx = zjlx;
    }

    public String getZjbh() {
        return zjbh;
    }

    public void setZjbh(String zjbh) {
        this.zjbh = zjbh;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getTxdz() {
        return txdz;
    }

    public void setTxdz(String txdz) {
        this.txdz = txdz;
    }

    public String getYb() {
        return yb;
    }

    public void setYb(String yb) {
        this.yb = yb;
    }

    public String getFzr() {
        return fzr;
    }

    public void setFzr(String fzr) {
        this.fzr = fzr;
    }

    public String getFzrlxdh() {
        return fzrlxdh;
    }

    public void setFzrlxdh(String fzrlxdh) {
        this.fzrlxdh = fzrlxdh;
    }

    public String getDwdm() {
        return dwdm;
    }

    public void setDwdm(String dwdm) {
        this.dwdm = dwdm;
    }

    public String getSfgz() {
        return sfgz;
    }

    public void setSfgz(String sfgz) {
        this.sfgz = sfgz;
    }

    public String getSftysf() {
        return sftysf;
    }

    public void setSftysf(String sftysf) {
        this.sftysf = sftysf;
    }

    public String getSfjcpttysf() {
        return sfjcpttysf;
    }

    public void setSfjcpttysf(String sfjcpttysf) {
        this.sfjcpttysf = sfjcpttysf;
    }

    public Date getBasj() {
        return basj;
    }

    public void setBasj(Date basj) {
        this.basj = basj;
    }

    public String getSfdz() {
        return sfdz;
    }

    public void setSfdz(String sfdz) {
        this.sfdz = sfdz;
    }

    public String getYhbh() {
        return yhbh;
    }

    public void setYhbh(String yhbh) {
        this.yhbh = yhbh;
    }

    public String getSjyhid() {
        return sjyhid;
    }

    public void setSjyhid(String sjyhid) {
        this.sjyhid = sjyhid;
    }

    public String getDlr() {
        return dlr;
    }

    public void setDlr(String dlr) {
        this.dlr = dlr;
    }

    public String getDlrzjlx() {
        return dlrzjlx;
    }

    public void setDlrzjlx(String dlrzjlx) {
        this.dlrzjlx = dlrzjlx;
    }

    public String getDlrzjh() {
        return dlrzjh;
    }

    public void setDlrzjh(String dlrzjh) {
        this.dlrzjh = dlrzjh;
    }

    public String getDlrlxdh() {
        return dlrlxdh;
    }

    public void setDlrlxdh(String dlrlxdh) {
        this.dlrlxdh = dlrlxdh;
    }

    public String getYhfr() {
        return yhfr;
    }

    public void setYhfr(String yhfr) {
        this.yhfr = yhfr;
    }

    public String getYhfrzjzl() {
        return yhfrzjzl;
    }

    public void setYhfrzjzl(String yhfrzjzl) {
        this.yhfrzjzl = yhfrzjzl;
    }

    public String getYhfrzjh() {
        return yhfrzjh;
    }

    public void setYhfrzjh(String yhfrzjh) {
        this.yhfrzjh = yhfrzjh;
    }

    public String getYhfrdh() {
        return yhfrdh;
    }

    public void setYhfrdh(String yhfrdh) {
        this.yhfrdh = yhfrdh;
    }

    public String getQlrxz() {
        return qlrxz;
    }

    public void setQlrxz(String qlrxz) {
        this.qlrxz = qlrxz;
    }

    public String getLzr() {
        return lzr;
    }

    public void setLzr(String lzr) {
        this.lzr = lzr;
    }

    public String getLzrzjh() {
        return lzrzjh;
    }

    public void setLzrzjh(String lzrzjh) {
        this.lzrzjh = lzrzjh;
    }
}
